@@ -91,6 +91,7 @@ namespace ost {
 #define	AUDIO_CODEC_MODULES	1
 #define	AUDIO_LINEAR_FRAMING	1
 #define	AUDIO_NATIVE_METHODS	1
+#define	AUDIO_RATE_RESAMPLER	1
 
 class __EXPORT AudioCodec;
 class __EXPORT AudioDevice;
@@ -374,6 +375,7 @@ public:
 		void clear(void);
 		void set(void);
 		void setFraming(timeout_t frame);
+		void setRate(Rate rate);
 	};
 
 	/**
@@ -518,6 +520,16 @@ public:
 	 */
 	static Rate getRate(Encoding encoding);
 
+	/**
+	 * Return optional rate setting effect.  Many codecs are
+	 * fixed rate.
+	 *
+	 * @return result rate for audio date.
+	 * @param encoding format.
+	 * @param requested rate.
+	 */
+	static Rate getRate(Encoding e, Rate request);
+
 	/**
 	 * Return frame timing for an audio encoding format.
 	 *
@@ -752,6 +764,29 @@ public:
 	static size_t maxFramesize(Info &info);
 };
 
+/**
+ * The AudioResample class is used to manage linear intropolation
+ * buffering for rate conversions.
+ *
+ * @author David Sugar <dyfet@ostel.com>
+ * @short linear intropolation and rate conversion.
+ */
+class __EXPORT AudioResample : public Audio
+{
+protected:
+	unsigned mfact, dfact, max;
+	unsigned gpos, ppos;
+	Sample last;
+	Linear buffer;
+
+public:
+	AudioResample(Rate mul, Rate div);
+	~AudioResample();
+
+	size_t process(Linear from, Linear to, size_t count);
+	size_t estimate(size_t count);
+};
+
 /**
  * The AudioTone class is used to create a frame of audio encoded single or
  * dualtones.  The frame will be iterated for each request, so a
