@@ -140,7 +140,7 @@ void AudioTone::dual(unsigned f1, unsigned f2, Level l1, Level l2)
 	silencer = false;
 }
 
-Audio::Linear AudioTone::getFrame(bool endian)
+Audio::Linear AudioTone::getFrame(void)
 {
 	unsigned count = samples;
 	Linear data = frame;
@@ -207,9 +207,6 @@ Audio::Linear AudioTone::getFrame(bool endian)
 		}
 	}
 
-	if(endian)
-		swapEndian(pcm16Mono, frame, samples);
-
 	return frame;
 }
 
